# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2013 Canonical
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

"""Reminders app autopilot tests."""

from __future__ import absolute_import

from autopilot.matchers import Eventually
from testtools.matchers import Equals, GreaterThan

from reminders_app.tests import RemindersAppTestCase, DatabaseMixin

import logging

logger = logging.getLogger(__name__)


class TestMainWindow(RemindersAppTestCase, DatabaseMixin):

    def setUp(self):
        logger.debug("Backing up existing online accounts database")
        self.addCleanup(self.backup_database())
        logger.debug("Wiping online accounts database")
        self.create_blank_db()
        logger.debug("Adding fake data to new database")
        self.add_account_to_database()
        super(TestMainWindow, self).setUp()
        self.assertThat(self.main_view.visible, Eventually(Equals(True)))

    def tearDown(self):
        super(TestMainWindow, self).tearDown()
        self.addCleanup(self.restore_database())

    def test_logon_to_Evernote(self):
        # Click on existing Evernote account
        # (the account must have be added before running tests)
        accountselectorPage = self.main_view.get_accountselectorpage()
        self.assertThat(accountselectorPage.visible, Eventually(Equals(True)))
        Evernoteaccount = self.main_view.get_evernote_account()

        self.pointing_device.click_object(Evernoteaccount)

        # verify we are logged on
        notesTab = self.main_view.switch_to_tab("NotesTab")
        self.assertThat(notesTab.visible, Eventually(Equals(True)))

    def test_download_list_of_notebooks(self):
        """test to check whether downloading a list from Notebooks from
           Evernote is successful or not """
        Evernoteaccount = self.main_view.get_evernote_account()
        self.pointing_device.click_object(Evernoteaccount)

        notebookTab = self.main_view.switch_to_tab("NotebookTab")
        self.assertThat(notebookTab.visible, Eventually(Equals(True)))

        notebookslistview = self.main_view.get_notespageListview()
        self.assertThat(notebookslistview.count,  Eventually(GreaterThan(0)))

    def test_nothing(self):
        print "Hi mom"
